package jp.co.argo21.nautica.ejbtest;

import javax.naming.NamingException;

import jp.co.argo21.nautica.workflow.soap.DefinitionRepository;
import jp.co.argo21.nautica.workflow.soap.DefinitionRepository_Service;
import jp.co.argo21.nautica.workflow.soap.RoleManager;
import jp.co.argo21.nautica.workflow.soap.RoleManager_Service;
import jp.co.argo21.nautica.workflow.soap.UserManager;
import jp.co.argo21.nautica.workflow.soap.UserManager_Service;
import jp.co.argo21.nautica.workflow.soap.WorkItemHandler;
import jp.co.argo21.nautica.workflow.soap.WorkItemHandler_Service;
import jp.co.argo21.nautica.workflow.soap.WorkflowAdminHandler;
import jp.co.argo21.nautica.workflow.soap.WorkflowAdminHandler_Service;
import jp.co.argo21.nautica.workflow.soap.WorkflowEngineHandler;
import jp.co.argo21.nautica.workflow.soap.WorkflowEngineHandler_Service;
import jp.co.argo21.nautica.workflow.soap.WorkflowServiceConnector;
import jp.co.argo21.nautica.workflow.soap.WorkflowServiceConnector_Service;



public class BeanSingleton
{
	private static BeanSingleton singleton = new BeanSingleton();
	
	private DefinitionRepository defRepository;
//	private RepositoryLoader repLoader;
	private WorkflowAdminHandler wfAdmin;
	private WorkflowEngineHandler wfEngine;
	private WorkflowServiceConnector wfConnector;
	private WorkItemHandler wfItem;
	private UserManager usrManager;
	private RoleManager roleManager;
	
	/**
	 * コンストラクタ
	 */
	private BeanSingleton()
	{
		try
		{
			setDefRepository();
			setWfServiceConnector();
//			setRepLoader();
			setWfEngine();
			setWfAdmin();
			setWfItem();
			setUsrManager();
			setRoleManager();
		}
		catch (NamingException e)
		{
			e.printStackTrace();
		}
	}
	
	/**
	 * BeanSingletonクラスのインスタンスを返す。
	 * @return BeanSingletonクラスのインスタンス
	 */
	public static BeanSingleton getInstance()
	{
		return singleton;
	}
	
	/**
	 * WorkflowServiceManagerクラスのインスタンスをセットする。
	 * @throws NamingException 
	 */
	private void setWfServiceConnector() throws NamingException
	{
		WorkflowServiceConnector_Service wsc = new WorkflowServiceConnector_Service();
		wfConnector = wsc.getWorkflowServiceConnectorPort();	
	}
	
	/**
	 * WorkflowServiceManagerクラスのインスタンスを返す。
	 * @return
	 */
	public WorkflowServiceConnector getWfServiceConnector()
	{
		return wfConnector;
	}
	
	/**
	 * DefinitionRepositoryクラスのインスタンスをセットする。
	 * @throws NamingException
	 */
	private void setDefRepository() throws NamingException
	{
		DefinitionRepository_Service dr = new DefinitionRepository_Service();
		defRepository = dr.getDefinitionRepositoryPort();
	}
	
	/**
	 * DefinitionRepositoryクラスのインスタンスを返す。
	 * @return DefinitionRepositoryクラスのインスタンス
	 */
	public DefinitionRepository getDefRepository()
	{
		return defRepository; 
	}
	
	/**
	 * WorkflowEngineHandlerクラスのインスタンスをセットする。
	 * @throws NamingException
	 */
	private void setWfEngine() throws NamingException
	{
		WorkflowEngineHandler_Service weh = new WorkflowEngineHandler_Service();
		wfEngine = weh.getWorkflowEngineHandlerPort();
	}
	
	/**
	 * WorkflowEngineHandlerクラスのインスタンスを返す。
	 * @return WorkflowEngineHandlerクラスのインスタンス
	 */
	public WorkflowEngineHandler getWfEngine()
	{
		return wfEngine;
	}
	
	/**
	 * WorkflowAdminHandlerクラスのインスタンスをセットする。
	 * @throws NamingException
	 */
	private void setWfAdmin() throws NamingException
	{
		WorkflowAdminHandler_Service wah = new WorkflowAdminHandler_Service();
		wfAdmin = wah.getWorkflowAdminHandlerPort();
	}
	
	/**
	 * WorkflowAdminHandlerクラスのインスタンスを返す。
	 * @return WorkflowAdminHandlerクラスのインスタンス
	 */
	public WorkflowAdminHandler getWfAdmin()
	{
		return wfAdmin;
	}
	
	/**
	 * WorkItemHandlerクラスのインスタンスをセットする。
	 * @throws NamingException
	 */
	private void setWfItem() throws NamingException
	{
		WorkItemHandler_Service wih = new WorkItemHandler_Service();
		wfItem = wih.getWorkItemHandlerPort();
	}
	
	/**
	 * WorkItemHandlerクラスのインスタンスを返す。
	 * @return WorkItemHandlerクラスのインスタンス
	 */
	public WorkItemHandler getWfItem()
	{
		return wfItem;
	}
	
	/**
	 * UserManagerクラスのインスタンスをセットする。
	 * @throws NamingException
	 */
	private void setUsrManager() throws NamingException
	{
		UserManager_Service um = new UserManager_Service();
		usrManager = um.getUserManagerPort();
	}
	
	/**
	 * UserManagerクラスのインスタンスを返す。
	 * @return UserManagerクラスのインスタンス
	 */
	public UserManager getUsrManager()
	{
		return usrManager;
	}
	
	/**
	 * RoleManagerクラスのインスタンスをセットする。
	 * @throws NamingException
	 */
	private void setRoleManager() throws NamingException
	{
		RoleManager_Service rm = new RoleManager_Service();
		roleManager = rm.getRoleManagerPort();
	}
	
	/**
	 * RoleManagerクラスのインスタンスを返す。
	 * @return
	 */
	public RoleManager getRoleManager()
	{
		return roleManager;
	}
}
